get_dictionary: Create a Data Dictionary

Description Usage Arguments Details Value

Description

'get_dictionary' creates a data dictionary from data frame variable attributes

Usage

1

Arguments

data

A data frame or tibble created using 'haven::read_sav'

Details

This function takes a data frame created using 'haven::read_sav' and returns a data frame with the SPSS metadata for each variable

Value

A data frame with the 'variable' names, SPSS 'class', and their respective 'value'


rvg02010/renata documentation built on May 16, 2019, 9:32 a.m.