get_val_labels: Create table of value labels

Description Usage Arguments Details Value

Description

'get_val_labels' creates a data frame of variable names and labels

Usage

1

Arguments

data

A data frame or tibble created using 'haven::read_sav'

Details

This function takes a data frame created using 'haven::read_sav' and returns a data frame with the SPSS labelled values for each variable

Value

A data frame with the 'variable', 'value' (which has labels), and respective SPSS 'value_name'


rvg02010/renata documentation built on May 16, 2019, 9:32 a.m.