get_var_labels: Create table of variable labels

Description Usage Arguments Details Value

Description

'get_var_labels' creates a data frame of variable names and labels

Usage

1

Arguments

data

A data frame or tibble created using 'haven::read_sav'

Details

This function takes a data frame created using 'haven::read_sav' and returns a data frame with the SPSS variable labels for each variable

Value

A data frame with the 'variable' names and respective SPSS 'label'


rvg02010/renata documentation built on May 16, 2019, 9:32 a.m.