Description Usage Arguments Details Value
'get_dictionary' creates a data dictionary from data frame variable attributes
1 |
data |
A data frame or tibble created using 'haven::read_sav' |
This function takes a data frame created using 'haven::read_sav' and returns a data frame with the SPSS metadata for each variable
A data frame with the 'variable' names, SPSS 'class', and their respective 'value'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.