Description Usage Arguments Details Value
'get_val_labels' creates a data frame of variable names and labels
1 |
data |
A data frame or tibble created using 'haven::read_sav' |
This function takes a data frame created using 'haven::read_sav' and returns a data frame with the SPSS labelled values for each variable
A data frame with the 'variable', 'value' (which has labels), and respective SPSS 'value_name'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.