Description Usage Arguments Details Value
'get_var_labels' creates a data frame of variable names and labels
1 |
data |
A data frame or tibble created using 'haven::read_sav' |
This function takes a data frame created using 'haven::read_sav' and returns a data frame with the SPSS variable labels for each variable
A data frame with the 'variable' names and respective SPSS 'label'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.